@@ -6,6 +6,7 @@ from typing import Any, Callable, Iterable, Optional
 import inspect, sys
 from importlib import import_module
 from .type_utils import make_list
+from .robust_readers import get_for_all_tabs,call_for_all_tabs
 class _LazyAttr:
     """Lazy resolver proxy to avoid import-time cycles.
     First use triggers actual import & attribute lookup.
@@ -188,8 +189,6 @@ def get_caller_dir():
     abspath = os.path.abspath(frame.filename)
     return os.path.dirname(abspath)
 def call_for_all_tabs():
-    get_for_all_tabs=  get_abstract_import(
-                        module='abstract_gui',
-                        symbol='get_for_all_tabs')
+    
     root = get_caller_dir()
     get_for_all_tabs(root)
